pub enum ToolResultAction {
Keep,
Rewrite(ToolOutput),
Stop(String),
}Expand description
Action for post-tool hooks.
Variants
Keep
Keep the current presentation.
Rewrite(ToolOutput)
Replace the effective presentation sent to the model and result-content telemetry.
Stop(String)
Stop the run.
Implementations
Sourceimpl ToolResultAction
impl ToolResultAction
Sourcepub fn rewrite(result: impl Into<String>) -> Self
pub fn rewrite(result: impl Into<String>) -> Self
Creates an action that replaces the effective presentation sent to the model and result-content telemetry.
The tool’s raw structured result remains unchanged.
Sourcepub fn rewrite_output(output: ToolOutput) -> Self
pub fn rewrite_output(output: ToolOutput) -> Self
Creates an action that replaces the effective model and telemetry presentation with explicit structured or multimodal output.