pub struct ReasoningDelta<'a> {
pub id: &'a str,
pub provider_id: Option<&'a str>,
pub delta: &'a str,
pub aggregated: &'a str,
}Expand description
Streaming reasoning delta.
Fields
id: &'a strRig-generated correlator for this reasoning part. It is stable across the part’s deltas and eventual completed reasoning item, but is never persisted as a provider-issued reasoning id.
provider_id: Option<&'a str>Provider-issued durable reasoning item id, when the wire provides one.
delta: &'a strNewly received reasoning fragment.
aggregated: &'a strReasoning text accumulated for this reasoning part through this delta.