pub struct WithBuilderTools { /* private fields */ }Expand description
Typestate indicating tools are being configured via the builder API.
In this state, you can continue adding tools via .tool(),
.dynamic_tool(), .dynamic_tools(), and .retrieved_tools(). When
.build() is called, a new ToolServer
will be created with all the configured tools.