Message

Enum Message 

pub enum Message {
    System {
        content: String,
    },
    User {
        content: OneOrMany<UserContent>,
    },
    Assistant {
        id: Option<String>,
        content: OneOrMany<AssistantContent>,
    },
}
A provider-agnostic chat message.

Messages are role-tagged and may contain one or many content items, including text, images, audio, documents, tool calls, and tool results. Provider modules are responsible for translating these generic messages into provider-native request bodies. That conversion may be lossy when a provider does not support a particular content type.

Variants



System

System message containing instruction text.

Fields

content: String


User

User message containing one or more content types defined by UserContent.

Fields



Assistant

Assistant message containing one or more content types defined by AssistantContent.

Fields

id: Option<String>

Provider-assigned assistant message ID, when available.

Implementations

Source

impl Message

pub fn rag_text(&self) -> Option<String>

This helper method is primarily used to extract the first string prompt from a Message. Since Message might have more than just text content, we need to find the first text.

pub fn system(text: impl Into<String>) -> Message

Helper constructor to make creating system messages easier.

pub fn user(text: impl Into<String>) -> Message

Helper constructor to make creating user messages easier.

pub fn assistant(text: impl Into<String>) -> Message

Helper constructor to make creating assistant messages easier.

pub fn assistant_with_id(id: String, text: impl Into<String>) -> Message

Helper constructor to make creating assistant messages easier.

pub fn tool_result(id: impl Into<String>, content: impl Into<String>) -> Message

Helper constructor to make creating tool result messages easier.

pub fn tool_result_with_call_id( id: impl Into<String>, call_id: Option<String>, content: impl Into<String>, ) -> Message