#[non_exhaustive]pub enum PromptError {
CompletionError(CompletionError),
MemoryError(MemoryError),
MaxTurnsError {
max_turns: usize,
chat_history: Box<Vec<Message>>,
prompt: Box<Message>,
},
PromptCancelled {
chat_history: Vec<Message>,
reason: String,
},
UnknownToolCall {
tool_name: String,
available_tools: Vec<String>,
allowed_tools: Vec<String>,
chat_history: Box<Vec<Message>>,
},
}Expand description
Errors from classic agent prompting.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CompletionError(CompletionError)
A provider completion failed.
MemoryError(MemoryError)
Conversation memory failed to load or persist history.
MaxTurnsError
The run exhausted its total model-call budget.
Fields
PromptCancelled
A prompting loop was cancelled.
Fields
UnknownToolCall
The model attempted to call a tool unavailable for the current turn.
Implementations
Sourceimpl PromptError
impl PromptError
Sourcepub fn provider_response_body(&self) -> Option<&str>
pub fn provider_response_body(&self) -> Option<&str>
Returns the provider response body exposed by a wrapped completion error.
Sourcepub fn provider_response_json(&self) -> Result<Option<Value>, Error>
pub fn provider_response_json(&self) -> Result<Option<Value>, Error>
Parses a wrapped provider response body as JSON when present.
Sourcepub fn provider_response_status(&self) -> Option<StatusCode>
pub fn provider_response_status(&self) -> Option<StatusCode>
Returns the HTTP status exposed by a wrapped completion error.