pub enum StructuredOutputError {
PromptError(Box<PromptError>),
DeserializationError(Error),
EmptyResponse,
}Expand description
Errors returned by typed structured prompting.
Variants
PromptError(Box<PromptError>)
The underlying classic run failed.
DeserializationError(Error)
The accepted response could not be deserialized.
EmptyResponse
The model returned no accepted content.
Implementations
Sourceimpl StructuredOutputError
impl StructuredOutputError
Sourcepub fn provider_response_body(&self) -> Option<&str>
pub fn provider_response_body(&self) -> Option<&str>
Returns the provider response body exposed by a wrapped prompt error.
Sourcepub fn provider_response_json(&self) -> Result<Option<Value>, Error>
pub fn provider_response_json(&self) -> Result<Option<Value>, Error>
Parses the provider response body of a wrapped prompt error as JSON when present.
Sourcepub fn provider_request_id(&self) -> Option<&str>
pub fn provider_request_id(&self) -> Option<&str>
Returns the provider transport request id exposed by a wrapped prompt error (rig#2314).
Sourcepub fn provider_response_status(&self) -> Option<StatusCode>
pub fn provider_response_status(&self) -> Option<StatusCode>
Returns the HTTP status exposed by a wrapped prompt error.
Sourcepub fn provider_response_headers(&self) -> Option<&HeaderMap>
pub fn provider_response_headers(&self) -> Option<&HeaderMap>
Returns the response headers exposed by a wrapped prompt error — e.g. Retry-After on a 429 (rig#2210).