#[non_exhaustive]pub struct Reasoning {
pub id: Option<String>,
pub content: Vec<ReasoningContent>,
}Expand description
Assistant reasoning payload with an optional provider-supplied identifier.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>Provider reasoning identifier, when supplied by the upstream API.
content: Vec<ReasoningContent>Ordered reasoning content blocks.
Implementations
Sourceimpl Reasoning
impl Reasoning
Sourcepub fn new_with_signature(input: &str, signature: Option<String>) -> Reasoning
pub fn new_with_signature(input: &str, signature: Option<String>) -> Reasoning
Create a new reasoning item from a single text item and optional signature.
Sourcepub fn optional_id(self, id: Option<String>) -> Reasoning
pub fn optional_id(self, id: Option<String>) -> Reasoning
Set or clear the provider reasoning ID.
Sourcepub fn multi(input: Vec<String>) -> Reasoning
pub fn multi(input: Vec<String>) -> Reasoning
Create reasoning content from multiple text blocks.
Sourcepub fn summaries(input: Vec<String>) -> Reasoning
pub fn summaries(input: Vec<String>) -> Reasoning
Create one reasoning block containing summary items.
Sourcepub fn display_text(&self) -> String
pub fn display_text(&self) -> String
Render reasoning as displayable text by joining text-like blocks with newlines.
Sourcepub fn first_text(&self) -> Option<&str>
pub fn first_text(&self) -> Option<&str>
Return the first text reasoning block, if present.
Sourcepub fn first_signature(&self) -> Option<&str>
pub fn first_signature(&self) -> Option<&str>
Return the first signature from text reasoning, if present.
Sourcepub fn encrypted_content(&self) -> Option<&str>
pub fn encrypted_content(&self) -> Option<&str>
Return the first encrypted reasoning payload, if present.