Struct ToolCall Copy item path Source pub struct ToolCall {
pub id: String ,
pub call_id: Option <String >,
pub function: ToolFunction ,
pub signature: Option <String >,
pub additional_params: Option <Value >,
}Expand description Describes a tool call with an id and function to call, generally produced by a provider.
Provider-supplied tool call ID.
Provider-specific call ID used by some APIs for tool result correlation.
Function name and JSON arguments requested by the model.
Optional cryptographic signature for the tool call.
This field is used by some providers (e.g., Google) to provide a signature
that can verify the authenticity and integrity of the tool call. When present,
it allows verification that the tool call was actually generated by the model
and has not been tampered with.
This is an optional, provider-specific feature and will be None for providers
that don’t support tool call signatures.
Additional provider-specific parameters to be sent to the completion model provider
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Instruments this type with the
current Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
Convert this value without routing structured data through a string.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.