pub struct Usage {
pub input_tokens: u64,
pub output_tokens: u64,
pub total_tokens: u64,
pub cached_input_tokens: u64,
pub cache_creation_input_tokens: u64,
pub tool_use_prompt_tokens: u64,
pub reasoning_tokens: u64,
}Expand description
Struct representing the token usage for a completion request.
If tokens used are 0, then the provider failed to supply token usage metrics.
Fields
input_tokens: u64The number of input (“prompt”) tokens used in a given request.
output_tokens: u64The number of output (“completion”) tokens used in a given request.
total_tokens: u64We store this separately as some providers may only report one number
cached_input_tokens: u64The number of input tokens read from a provider-managed cache
cache_creation_input_tokens: u64The number of input tokens written to a provider-managed cache
tool_use_prompt_tokens: u64The number of tool-use prompt tokens used in a given request.
reasoning_tokens: u64The number of tokens spent on internal reasoning / “thoughts” by reasoning-capable models (e.g. Gemini thinking, Anthropic extended thinking, OpenAI o-series).
Implementations