pub struct ImageGenerationResponse<T> {
pub image: Vec<u8>,
pub response: T,
}Available on crate feature
image only.Expand description
A unified response for a model image generation, returning both the image and the raw response.
Fields
image: Vec<u8>response: TTrait Implementations
Sourceimpl<T> Debug for ImageGenerationResponse<T>where
T: Debug,
impl<T> Debug for ImageGenerationResponse<T>where
T: Debug,
Sourceimpl TryFrom<GenerateContentResponse> for ImageGenerationResponse<GenerateContentResponse>
impl TryFrom<GenerateContentResponse> for ImageGenerationResponse<GenerateContentResponse>
Sourcetype Error = ImageGenerationError
type Error = ImageGenerationError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: GenerateContentResponse,
) -> Result<ImageGenerationResponse<GenerateContentResponse>, <ImageGenerationResponse<GenerateContentResponse> as TryFrom<GenerateContentResponse>>::Error>
fn try_from( value: GenerateContentResponse, ) -> Result<ImageGenerationResponse<GenerateContentResponse>, <ImageGenerationResponse<GenerateContentResponse> as TryFrom<GenerateContentResponse>>::Error>
Performs the conversion.
Sourceimpl TryFrom<ImageGenerationResponse> for ImageGenerationResponse<ImageGenerationResponse>
impl TryFrom<ImageGenerationResponse> for ImageGenerationResponse<ImageGenerationResponse>
Sourcetype Error = ImageGenerationError
type Error = ImageGenerationError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ImageGenerationResponse,
) -> Result<ImageGenerationResponse<ImageGenerationResponse>, <ImageGenerationResponse<ImageGenerationResponse> as TryFrom<ImageGenerationResponse>>::Error>
fn try_from( value: ImageGenerationResponse, ) -> Result<ImageGenerationResponse<ImageGenerationResponse>, <ImageGenerationResponse<ImageGenerationResponse> as TryFrom<ImageGenerationResponse>>::Error>
Performs the conversion.
Sourceimpl TryFrom<ImageGenerationResponse> for ImageGenerationResponse<ImageGenerationResponse>
impl TryFrom<ImageGenerationResponse> for ImageGenerationResponse<ImageGenerationResponse>
Sourcetype Error = ImageGenerationError
type Error = ImageGenerationError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ImageGenerationResponse,
) -> Result<ImageGenerationResponse<ImageGenerationResponse>, <ImageGenerationResponse<ImageGenerationResponse> as TryFrom<ImageGenerationResponse>>::Error>
fn try_from( value: ImageGenerationResponse, ) -> Result<ImageGenerationResponse<ImageGenerationResponse>, <ImageGenerationResponse<ImageGenerationResponse> as TryFrom<ImageGenerationResponse>>::Error>
Performs the conversion.
Sourceimpl TryFrom<ImageGenerationResponse> for ImageGenerationResponse<ImageGenerationResponse>
impl TryFrom<ImageGenerationResponse> for ImageGenerationResponse<ImageGenerationResponse>
Sourcetype Error = ImageGenerationError
type Error = ImageGenerationError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ImageGenerationResponse,
) -> Result<ImageGenerationResponse<ImageGenerationResponse>, <ImageGenerationResponse<ImageGenerationResponse> as TryFrom<ImageGenerationResponse>>::Error>
fn try_from( value: ImageGenerationResponse, ) -> Result<ImageGenerationResponse<ImageGenerationResponse>, <ImageGenerationResponse<ImageGenerationResponse> as TryFrom<ImageGenerationResponse>>::Error>
Performs the conversion.
Sourceimpl TryFrom<ImageGenerationResponse> for ImageGenerationResponse<ImageGenerationResponse>
impl TryFrom<ImageGenerationResponse> for ImageGenerationResponse<ImageGenerationResponse>
Sourcetype Error = ImageGenerationError
type Error = ImageGenerationError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ImageGenerationResponse,
) -> Result<ImageGenerationResponse<ImageGenerationResponse>, <ImageGenerationResponse<ImageGenerationResponse> as TryFrom<ImageGenerationResponse>>::Error>
fn try_from( value: ImageGenerationResponse, ) -> Result<ImageGenerationResponse<ImageGenerationResponse>, <ImageGenerationResponse<ImageGenerationResponse> as TryFrom<ImageGenerationResponse>>::Error>
Performs the conversion.