pub struct Provided<T>(pub T);Expand description
Marker struct representing provided data in a request builder.
The generic type T represents the type of the provided data.
Tuple Fields
0: TTrait Implementations
impl<T> Copy for Provided<T>where
T: Copy,
Sourceimpl<'de, T> Deserialize<'de> for Provided<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Provided<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Provided<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Provided<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T> Serialize for Provided<T>where
T: Serialize,
impl<T> Serialize for Provided<T>where
T: Serialize,
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more