pub enum Content {
Text {
text: String,
citations: Vec<Citation>,
cache_control: Option<CacheControl>,
},
Image {
source: ImageSource,
cache_control: Option<CacheControl>,
},
ToolUse {
id: String,
name: String,
input: Value,
},
ServerToolUse {
id: String,
name: String,
input: Value,
},
WebSearchToolResult {
tool_use_id: String,
content: Value,
},
CodeExecutionToolResult {
tool_use_id: String,
content: Value,
},
ToolResult {
tool_use_id: String,
content: OneOrMany<ToolResultContent>,
is_error: Option<bool>,
cache_control: Option<CacheControl>,
},
Document {
source: DocumentSource,
title: Option<String>,
context: Option<String>,
citations: Option<CitationsConfig>,
cache_control: Option<CacheControl>,
},
Thinking {
thinking: String,
signature: Option<String>,
},
RedactedThinking {
data: String,
},
}Variants
Text
Fields

citations: Vec<Citation>Citations returned by Claude pointing back into the source documents. Empty (and skipped during serialization) on request-side blocks.

cache_control: Option<CacheControl>Image
ToolUse
ServerToolUse
WebSearchToolResult
CodeExecutionToolResult
The result of an Anthropic-hosted code execution tool call.
ToolResult
Document
Fields

source: DocumentSource
context: Option<String>Optional document context (e.g. metadata), passed to the model but
not citable. Useful for storing additional information about the
document that should not appear in citation cited_text.

citations: Option<CitationsConfig>Configuration for enabling citations on this document. When enabled
is true, Claude returns citation metadata on response text blocks
pointing back into this document’s content.

cache_control: Option<CacheControl>Thinking
RedactedThinking