pub struct CopilotBuilder { /* private fields */ }Trait Implementations
Sourceimpl Clone for CopilotBuilder
impl Clone for CopilotBuilder
Sourcefn clone(&self) -> CopilotBuilder
fn clone(&self) -> CopilotBuilder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CopilotBuilder
impl Debug for CopilotBuilder
Sourceimpl Default for CopilotBuilder
impl Default for CopilotBuilder
Sourcefn default() -> CopilotBuilder
fn default() -> CopilotBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for CopilotBuilder
impl ProviderBuilder for CopilotBuilder
Sourcetype Extension<H: HttpClientExt> = CopilotExt
type Extension<H: HttpClientExt> = CopilotExt
Provider extension type built for a concrete HTTP backend.
Sourcetype ApiKey = CopilotAuth
type ApiKey = CopilotAuth
API key input type accepted by the provider’s client builder.
Sourcefn build<H>(
builder: &ClientBuilder<CopilotBuilder, <CopilotBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<CopilotBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
fn build<H>(
builder: &ClientBuilder<CopilotBuilder, <CopilotBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<CopilotBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>, Error>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>, Error>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersAuto Trait Implementations
impl !RefUnwindSafe for CopilotBuilder
impl !UnwindSafe for CopilotBuilder
impl Freeze for CopilotBuilder
impl Send for CopilotBuilder
impl Sync for CopilotBuilder
impl Unpin for CopilotBuilder
impl UnsafeUnpin for CopilotBuilder