pub struct DeepSeekExtBuilder;Trait Implementations
Sourceimpl Clone for DeepSeekExtBuilder
impl Clone for DeepSeekExtBuilder
Sourcefn clone(&self) -> DeepSeekExtBuilder
fn clone(&self) -> DeepSeekExtBuilder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeepSeekExtBuilder
Sourceimpl Debug for DeepSeekExtBuilder
impl Debug for DeepSeekExtBuilder
Sourceimpl Default for DeepSeekExtBuilder
impl Default for DeepSeekExtBuilder
Sourcefn default() -> DeepSeekExtBuilder
fn default() -> DeepSeekExtBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for DeepSeekExtBuilder
impl ProviderBuilder for DeepSeekExtBuilder
Sourcetype Extension<H: HttpClientExt> = DeepSeekExt
type Extension<H: HttpClientExt> = DeepSeekExt
Provider extension type built for a concrete HTTP backend.
Sourcetype ApiKey = BearerAuth
type ApiKey = BearerAuth
API key input type accepted by the provider’s client builder.
Sourcefn build<H>(
_builder: &ClientBuilder<DeepSeekExtBuilder, <DeepSeekExtBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<DeepSeekExtBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
fn build<H>(
_builder: &ClientBuilder<DeepSeekExtBuilder, <DeepSeekExtBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<DeepSeekExtBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>, Error>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>, Error>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersAuto Trait Implementations
impl Freeze for DeepSeekExtBuilder
impl RefUnwindSafe for DeepSeekExtBuilder
impl Send for DeepSeekExtBuilder
impl Sync for DeepSeekExtBuilder
impl Unpin for DeepSeekExtBuilder
impl UnsafeUnpin for DeepSeekExtBuilder
impl UnwindSafe for DeepSeekExtBuilder