pub struct Exchange<C, R> {
pub call_id: Option<String>,
pub calls: Vec<C>,
pub results: Vec<R>,
}Expand description
Groups tool calls and results of one built-in tool family for a single interaction.
Fields
call_id: Option<String>Call identifier used to match calls to results.
calls: Vec<C>One or more tool calls.
results: Vec<R>One or more tool results.
Implementations
Sourceimpl Exchange<GoogleSearchCallContent, GoogleSearchResultContent>
impl Exchange<GoogleSearchCallContent, GoogleSearchResultContent>
Sourcepub fn queries(&self) -> Vec<String>
pub fn queries(&self) -> Vec<String>
Collects all queries from the stored Google Search tool calls.
Sourcepub fn result_items(&self) -> Vec<GoogleSearchResult>
pub fn result_items(&self) -> Vec<GoogleSearchResult>
Collects all Google Search result entries from tool results.
Sourceimpl Exchange<UrlContextCallContent, UrlContextResultContent>
impl Exchange<UrlContextCallContent, UrlContextResultContent>
Sourcepub fn result_items(&self) -> Vec<UrlContextResult>
pub fn result_items(&self) -> Vec<UrlContextResult>
Collects all URL context result entries from tool results.