pub struct GoogleSearchExchange {
pub call_id: Option<String>,
pub calls: Vec<GoogleSearchCallContent>,
pub results: Vec<GoogleSearchResultContent>,
}Expand description
Groups Google Search tool calls and results for a single interaction.
Fields
call_id: Option<String>Call identifier used to match calls to results.
calls: Vec<GoogleSearchCallContent>One or more Google Search tool calls.
results: Vec<GoogleSearchResultContent>One or more Google Search tool results.
Implementations
Sourceimpl GoogleSearchExchange
impl GoogleSearchExchange
Sourcepub fn queries(&self) -> Vec<String>
pub fn queries(&self) -> Vec<String>
Collects all queries from the stored Google Search tool calls.
Sourcepub fn result_items(&self) -> Vec<GoogleSearchResult>
pub fn result_items(&self) -> Vec<GoogleSearchResult>
Collects all Google Search result entries from tool results.