TruncationStrategy

Enum TruncationStrategy 

pub enum TruncationStrategy {
    Auto,
    Disabled,
}
The truncation strategy. When using auto, if the context of this response and previous ones exceeds the model’s context window size, the model will truncate the response to fit the context window by dropping input items in the middle of the conversation. Otherwise, does nothing (and is disabled by default).

Variants



Auto



Disabled