pub struct OutputFunctionCall {
pub id: String,
pub arguments: Value,
pub call_id: String,
pub name: String,
pub status: ToolStatus,
}Expand description
An OpenAI Responses API tool call. A call ID will be returned that must be used when creating a tool result to send back to OpenAI as a message input, otherwise an error will be received.
Fields
id: StringProvider-assigned fc_... item ID. The Responses API rejects
function_call input IDs that are not native fc item IDs, so IDs
minted outside the Responses API (by Rig’s agent loop or another
provider) are omitted on serialization and the call is paired with its
output by call_id alone.
arguments: Valuecall_id: Stringname: Stringstatus: ToolStatusTrait Implementations
Sourceimpl Clone for OutputFunctionCall
impl Clone for OutputFunctionCall
Sourcefn clone(&self) -> OutputFunctionCall
fn clone(&self) -> OutputFunctionCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputFunctionCall
impl Debug for OutputFunctionCall
Sourceimpl<'de> Deserialize<'de> for OutputFunctionCall
impl<'de> Deserialize<'de> for OutputFunctionCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<OutputFunctionCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<OutputFunctionCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for OutputFunctionCall
impl PartialEq for OutputFunctionCall
Sourceimpl Serialize for OutputFunctionCall
impl Serialize for OutputFunctionCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for OutputFunctionCall