pub struct Reasoning {
pub effort: Option<ReasoningEffort>,
pub summary: Option<ReasoningSummaryLevel>,
pub mode: Option<ReasoningMode>,
pub context: Option<ReasoningContext>,
}Expand description
Add reasoning to a CompletionRequest.
Example
use rig_core::providers::openai::responses_api::{
Reasoning, ReasoningContext, ReasoningEffort, ReasoningMode,
};
// GPT-5.6 reasoning controls: effort, pro mode, and persisted-reasoning context.
let reasoning = Reasoning::new()
.with_effort(ReasoningEffort::Max)
.with_mode(ReasoningMode::Pro)
.with_context(ReasoningContext::AllTurns);Fields
effort: Option<ReasoningEffort>How much effort you want the model to put into thinking/reasoning.
summary: Option<ReasoningSummaryLevel>How much effort you want the model to put into writing the reasoning summary.
mode: Option<ReasoningMode>The reasoning mode. Independent from effort; the standard mode is
represented by omitting the field. Supported by the GPT-5.6 model family.
context: Option<ReasoningContext>How persisted reasoning is carried across turns. Supported by the GPT-5.6 model family.
Implementations
Sourceimpl Reasoning
impl Reasoning
Sourcepub fn with_effort(self, reasoning_effort: ReasoningEffort) -> Reasoning
pub fn with_effort(self, reasoning_effort: ReasoningEffort) -> Reasoning
Adds reasoning effort.
Sourcepub fn with_summary_level(
self,
reasoning_summary_level: ReasoningSummaryLevel,
) -> Reasoning
pub fn with_summary_level( self, reasoning_summary_level: ReasoningSummaryLevel, ) -> Reasoning
Adds summary level (how detailed the reasoning summary will be).
Sourcepub fn with_mode(self, reasoning_mode: ReasoningMode) -> Reasoning
pub fn with_mode(self, reasoning_mode: ReasoningMode) -> Reasoning
Sets the reasoning mode (e.g. pro mode on GPT-5.6 models).
Sourcepub fn with_context(self, reasoning_context: ReasoningContext) -> Reasoning
pub fn with_context(self, reasoning_context: ReasoningContext) -> Reasoning
Sets how persisted reasoning is carried across turns (GPT-5.6 models).