pub struct CompletionRequest {
pub model: String,
pub messages: Vec<Message>,
pub tools: Vec<ToolDefinition>,
pub tool_choice: Option<ToolChoice>,
pub temperature: Option<f64>,
pub max_tokens: Option<u64>,
pub additional_params: Option<Value>,
}Fields
model: Stringmessages: Vec<Message>tools: Vec<ToolDefinition>tool_choice: Option<ToolChoice>temperature: Option<f64>max_tokens: Option<u64>additional_params: Option<Value>Trait Implementations
Sourceimpl Clone for CompletionRequest
impl Clone for CompletionRequest
Sourcefn clone(&self) -> CompletionRequest
fn clone(&self) -> CompletionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompletionRequest
impl Debug for CompletionRequest
Sourceimpl<'de> Deserialize<'de> for CompletionRequest
impl<'de> Deserialize<'de> for CompletionRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CompletionRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CompletionRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for CompletionRequest
impl Serialize for CompletionRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<(&str, CompletionRequest)> for CompletionRequest
impl TryFrom<(&str, CompletionRequest)> for CompletionRequest
Sourcetype Error = CompletionError
type Error = CompletionError
The type returned in the event of a conversion error.
Sourcefn try_from(
_: (&str, CompletionRequest),
) -> Result<CompletionRequest, <CompletionRequest as TryFrom<(&str, CompletionRequest)>>::Error>
fn try_from( _: (&str, CompletionRequest), ) -> Result<CompletionRequest, <CompletionRequest as TryFrom<(&str, CompletionRequest)>>::Error>
Performs the conversion.
Sourceimpl TryFrom<(String, CompletionRequest)> for CompletionRequest
impl TryFrom<(String, CompletionRequest)> for CompletionRequest
Sourcetype Error = CompletionError
type Error = CompletionError
The type returned in the event of a conversion error.
Sourcefn try_from(
_: (String, CompletionRequest),
) -> Result<CompletionRequest, <CompletionRequest as TryFrom<(String, CompletionRequest)>>::Error>
fn try_from( _: (String, CompletionRequest), ) -> Result<CompletionRequest, <CompletionRequest as TryFrom<(String, CompletionRequest)>>::Error>
Performs the conversion.
Sourceimpl TryFrom<OpenAIRequestParams> for CompletionRequest
impl TryFrom<OpenAIRequestParams> for CompletionRequest
Sourcetype Error = CompletionError
type Error = CompletionError
The type returned in the event of a conversion error.
Sourcefn try_from(
params: OpenAIRequestParams,
) -> Result<CompletionRequest, <CompletionRequest as TryFrom<OpenAIRequestParams>>::Error>
fn try_from( params: OpenAIRequestParams, ) -> Result<CompletionRequest, <CompletionRequest as TryFrom<OpenAIRequestParams>>::Error>
Performs the conversion.
Sourceimpl TryFrom<OpenRouterRequestParams<'_>> for CompletionRequest
impl TryFrom<OpenRouterRequestParams<'_>> for CompletionRequest
Sourcetype Error = CompletionError
type Error = CompletionError
The type returned in the event of a conversion error.
Sourcefn try_from(
params: OpenRouterRequestParams<'_>,
) -> Result<CompletionRequest, <CompletionRequest as TryFrom<OpenRouterRequestParams<'_>>>::Error>
fn try_from( params: OpenRouterRequestParams<'_>, ) -> Result<CompletionRequest, <CompletionRequest as TryFrom<OpenRouterRequestParams<'_>>>::Error>
Performs the conversion.