MockStreamEvent

Enum MockStreamEvent 

pub enum MockStreamEvent {
    Text(String),
    TextStart {
        additional_params: Option<Value>,
    },
    TextAdditionalParams(Value),
    ToolCall {
        id: String,
        name: String,
        arguments: Value,
        call_id: Option<String>,
    },
    ToolCallDelta {
        id: String,
        internal_call_id: String,
        content: ToolCallDeltaContent,
    },
    Reasoning {
        id: Option<String>,
        content: ReasoningContent,
    },
    ReasoningDelta {
        id: Option<String>,
        reasoning: String,
    },
    MessageId(String),
    Unknown(Value),
    FinalResponse(MockResponse),
    Error(MockError),
}
Available on crate features test-utils only.
Scripted streaming event yielded by MockCompletionModel.

Variants



Text(String)

Text chunk.



TextStart

Start a new text content block with optional provider metadata.

Fields

additional_params: Option<Value>


TextAdditionalParams(Value)

Provider-specific metadata for the current text content block.



ToolCall

Complete tool call event.

Fields

name: String
arguments: Value
call_id: Option<String>


ToolCallDelta

Tool call delta event.

Fields

internal_call_id: String


Reasoning

Complete reasoning event.



ReasoningDelta

Reasoning delta event.

Fields

reasoning: String


MessageId(String)

Provider-assigned message ID.



Unknown(Value)

Provider-native output item that Rig does not model.



FinalResponse(MockResponse)

Final raw response carrying optional usage.



Error(MockError)

Stream error.

Implementations

Source

impl MockStreamEvent

pub fn text(text: impl Into<String>) -> MockStreamEvent

Create a text chunk.

pub fn text_start(additional_params: Option<Value>) -> MockStreamEvent

Start a new text content block.

pub fn text_additional_params(additional_params: Value) -> MockStreamEvent

Add provider-specific metadata to the current text content block.

pub fn tool_call( id: impl Into<String>, name: impl Into<String>, arguments: Value, ) -> MockStreamEvent

Create a complete tool call event.

pub fn with_call_id(self, call_id: impl Into<String>) -> MockStreamEvent

Attach a provider-specific call ID to a complete tool call event.

pub fn tool_call_name_delta( id: impl Into<String>, internal_call_id: impl Into<String>, name: impl Into<String>, ) -> MockStreamEvent

Create a tool call name delta.

pub fn tool_call_arguments_delta( id: impl Into<String>, internal_call_id: impl Into<String>, arguments: impl Into<String>, ) -> MockStreamEvent

Create a tool call arguments delta.

pub fn reasoning(reasoning: impl Into<String>) -> MockStreamEvent

Create a complete reasoning event.

pub fn with_reasoning_id( self, reasoning_id: impl Into<String>, ) -> MockStreamEvent

Attach a provider-specific reasoning ID to a complete reasoning event.

pub fn reasoning_delta( id: Option<impl Into<String>>, reasoning: impl Into<String>, ) -> MockStreamEvent

Create a reasoning delta event.

pub fn message_id(id: impl Into<String>) -> MockStreamEvent

Create a provider-assigned message ID event.

pub fn unknown(value: Value) -> MockStreamEvent

Create an unmodeled provider output item.

pub fn final_response(usage: Usage) -> MockStreamEvent

Create a final response event with usage.

pub fn final_response_with_default_usage() -> MockStreamEvent

Create a final response event with default zero usage.

pub fn final_response_with_total_tokens(total_tokens: u64) -> MockStreamEvent

Create a final response event whose usage has only total_tokens set.

pub fn error(message: impl Into<String>) -> MockStreamEvent

Create a stream error event.