Module builtin

Module builtin 

Built-in tools shipped with rig that agents can use out of the box.

Modules

think

Structs

ThinkTool
The Think tool allows agents to stop and think in complex tool use situations.