Module wasm_compat

Module wasm_compat 

Structs

Elapsed
Error returned by timeout when the future does not complete in time.

Traits

WasmCompatSendNot (target_os=unknown and WebAssembly)
Send on native targets, a no-op marker on browser wasm.
WasmCompatSendStreamNot (target_os=unknown and WebAssembly)
Streaming response bound that includes Send on native targets.
WasmCompatSyncNot (target_os=unknown and WebAssembly)
Sync on native targets, a no-op marker on browser wasm.

Functions

timeout
Await future, returning Err(Elapsed) if it does not complete within duration.

Type Aliases

WasmBoxedFutureNot (target_os=unknown and WebAssembly)
Boxed future type that includes Send, except on browser wasm.