InMemoryVectorStore

Struct InMemoryVectorStore 

pub struct InMemoryVectorStore<D>
where D: Serialize,
{ /* private fields */ }
InMemoryVectorStore is a simple in-memory vector store that stores embeddings in-memory using a HashMap.

Implementations

Source

impl<D> InMemoryVectorStore<D>
where D: Serialize + Eq,

pub fn builder() -> InMemoryVectorStoreBuilder<D>

Create a new builder for configuring an InMemoryVectorStore.

Examples
use rig_core::vector_store::InMemoryVectorStore;

let store = InMemoryVectorStore::<String>::builder()
    .with_lsh()
    .documents(documents)
    .build();
pub fn from_documents( documents: impl IntoIterator<Item = (D, OneOrMany<Embedding>)>, ) -> InMemoryVectorStore<D>

Create a new InMemoryVectorStore from documents and their corresponding embeddings. Ids are automatically generated have will have the form "doc{n}" where n is the index of the document.

Uses BruteForce index strategy by default. For custom index strategies, use InMemoryVectorStore::builder.

pub fn from_documents_with_ids( documents: impl IntoIterator<Item = (impl ToString, D, OneOrMany<Embedding>)>, ) -> InMemoryVectorStore<D>

Create a new InMemoryVectorStore from documents and their corresponding embeddings with ids.

Uses BruteForce index strategy by default. For custom index strategies, use InMemoryVectorStore::builder.

pub fn from_documents_with_id_f( documents: impl IntoIterator<Item = (D, OneOrMany<Embedding>)>, f: fn(&D) -> String, ) -> InMemoryVectorStore<D>

Create a new InMemoryVectorStore from documents and their corresponding embeddings. Document ids are generated using the provided function.

Uses BruteForce index strategy by default. For custom index strategies, use InMemoryVectorStore::builder.

pub fn add_documents( &mut self, documents: impl IntoIterator<Item = (D, OneOrMany<Embedding>)>, )

Add documents and their corresponding embeddings to the store. Ids are automatically generated have will have the form "doc{n}" where n is the index of the document.

pub fn add_documents_with_ids( &mut self, documents: impl IntoIterator<Item = (impl ToString, D, OneOrMany<Embedding>)>, )

Add documents and their corresponding embeddings to the store with ids.

pub fn add_documents_with_id_f( &mut self, documents: Vec<(D, OneOrMany<Embedding>)>, f: fn(&D) -> String, )

Add documents and their corresponding embeddings to the store. Document ids are generated using the provided function.

pub fn get_document<T>(&self, id: &str) -> Result<Option<T>, VectorStoreError>
where T: for<'a> Deserialize<'a>,

Get the document by its id and deserialize it into the given type.

Source

impl<D> InMemoryVectorStore<D>
where D: Serialize,

pub fn index<M>(self, model: M) -> InMemoryVectorIndex<M, D>
where M: EmbeddingModel,

pub fn iter( &self, ) -> impl Iterator<Item = (&String, &(D, OneOrMany<Embedding>))>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool