pub fn mock_final(usage: Usage) -> StreamFinalAvailable on crate feature
test-utils only.Expand description
Build the terminal record the mock model yields, carrying usage.
pub fn mock_final(usage: Usage) -> StreamFinaltest-utils only.Build the terminal record the mock model yields, carrying usage.