validate_rewritten_arguments

Function validate_rewritten_arguments 

pub fn validate_rewritten_arguments(
    scenario: &'static str,
    observations: &[Value],
    expected_fields: &Value,
) -> Result<(), ScenarioError>
Available on crate feature test-utils only.
Validate that every observed tool invocation contains the expected rewritten argument fields while allowing unrelated original fields to remain.