pub struct MockCompletionModel { /* private fields */ }Available on crate feature
test-utils only.Expand description
A cloneable scripted CompletionModel for tests.
Each completion or stream call consumes exactly one scripted turn. If no turn
is available, the model returns CompletionError::ProviderError with a
clear message instead of repeating previous responses.
Implementations
Sourceimpl MockCompletionModel
impl MockCompletionModel
Sourcepub fn new(turns: impl IntoIterator<Item = MockTurn>) -> MockCompletionModel
Available on crate features test-utils only.
pub fn new(turns: impl IntoIterator<Item = MockTurn>) -> MockCompletionModel
test-utils only.Create a mock model from scripted non-streaming turns.
Sourcepub fn text(text: impl Into<String>) -> MockCompletionModel
Available on crate features test-utils only.
pub fn text(text: impl Into<String>) -> MockCompletionModel
test-utils only.Create a mock model that returns one text completion.
Sourcepub fn from_turns(
turns: impl IntoIterator<Item = MockTurn>,
) -> MockCompletionModel
Available on crate features test-utils only.
pub fn from_turns( turns: impl IntoIterator<Item = MockTurn>, ) -> MockCompletionModel
test-utils only.Create a mock model from scripted non-streaming turns.
Sourcepub fn from_stream_turns(
stream_turns: impl IntoIterator<Item = impl IntoIterator<Item = MockStreamEvent>>,
) -> MockCompletionModel
Available on crate features test-utils only.
pub fn from_stream_turns( stream_turns: impl IntoIterator<Item = impl IntoIterator<Item = MockStreamEvent>>, ) -> MockCompletionModel
test-utils only.Create a mock model from scripted streaming turns.
Sourcepub fn requests(&self) -> Vec<CompletionRequest>
Available on crate features test-utils only.
pub fn requests(&self) -> Vec<CompletionRequest>
test-utils only.Return cloned requests received by this model.
Sourcepub fn request_count(&self) -> usize
Available on crate features test-utils only.
pub fn request_count(&self) -> usize
test-utils only.Return the number of requests received by this model.