pub struct MockResponse { /* private fields */ }Available on crate feature
test-utils only.Expand description
Raw mock response used by completion and streaming test utilities.
Implementations
Sourceimpl MockResponse
impl MockResponse
Sourcepub fn new() -> MockResponse
Available on crate features test-utils only.
pub fn new() -> MockResponse
test-utils only.Create a mock raw response without token usage (zero-valued usage,
Usage’s documented sentinel for missing provider metrics).
Sourcepub fn with_usage(usage: Usage) -> MockResponse
Available on crate features test-utils only.
pub fn with_usage(usage: Usage) -> MockResponse
test-utils only.Create a mock raw response carrying token usage.
Sourcepub fn with_total_tokens(total_tokens: u64) -> MockResponse
Available on crate features test-utils only.
pub fn with_total_tokens(total_tokens: u64) -> MockResponse
test-utils only.Create a mock raw response whose usage has only total_tokens set.