MockToolIndex

Struct MockToolIndex 

pub struct MockToolIndex { /* private fields */ }
Available on crate feature test-utils only.
A vector index that returns a predefined list of tool IDs from top_n_ids.

Implementations

Source

impl MockToolIndex

pub fn new(tool_ids: impl IntoIterator<Item = impl Into<String>>) -> Self

Create a tool index that returns the given IDs in order.