Module builtin

Module builtin 

Built-in portable tools exposed through the classic runtime namespace.

Modules

think

Structs

ThinkTool
The Think tool allows agents to stop and think in complex tool use situations.