pub enum ToolCallAction {
Run,
Rewrite(Value),
Skip(String),
Stop(String),
}Expand description
Action for pre-tool hooks.
Variants
Run
Execute with the current arguments.
Rewrite(Value)
Execute with replacement arguments.
Skip(String)
Do not execute; return this feedback to the model.
Stop(String)
Stop the run.
Implementations
Sourceimpl ToolCallAction
impl ToolCallAction
Sourcepub fn rewrite(args: impl Into<Value>) -> Self
pub fn rewrite(args: impl Into<Value>) -> Self
Creates an action that replaces the arguments passed to the tool.
Sourcepub fn try_rewrite<T: Serialize>(args: &T) -> Result<Self, Error>
pub fn try_rewrite<T: Serialize>(args: &T) -> Result<Self, Error>
Serializes replacement arguments and creates a rewrite action.
Returns an error when args cannot be represented as JSON.