High-level streaming prompting traits for the classic agent runtime.
Structs
- Pause
Control - Control for pausing and resuming a streaming response
- RawStreaming
Tool Call - Describes a streaming tool call response (in its entirety)
- Streaming
Completion Response - The response from a streaming completion request;
message and response are populated at the end of the
innerstream.
Enums
- RawStreaming
Choice - Enum representing a streaming chunk from the model
- Streamed
Assistant Content - Describes responses from a streamed provider response which is either text, a tool call or a final usage response.
- Streamed
User Content - Streamed user content. This content is primarily used to represent tool results from tool calls made during a multi-turn/step agent prompt.
- Tool
Call Delta Content - The content of a tool call delta - either the tool name or argument data
Traits
- Streaming
Chat - High-level streaming chat interface with caller-provided history.
- Streaming
Prompt - High-level one-shot streaming prompt interface.
Type Aliases
- Streaming
Result Not ( target_os=unknownand WebAssembly) - Provider stream of raw completion chunks on native targets.